@@ -1,7 +1,7 @@
 /*
 * Open Chinese Convert
 *
-* Copyright 2010 BYVoid <byvoid1@gmail.com>
+* Copyright 2010 BYVoid <byvoid.kcp@gmail.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
@@ -79,9 +79,10 @@ char * opencc_convert_utf8(opencc_t t_opencc, const char * inbuf, size_t length)
 	size_t outsize = outbuf_len;
 	char * original_outbuf = (char *) malloc(sizeof(char) * (outbuf_len + 1));
 	char * outbuf = original_outbuf;
+	original_outbuf[0] = '\0';
 
 	/* 設置轉換緩衝區空間 */
-	size_t wbufsize = length;
+	size_t wbufsize = length + 64;
 	ucs4_t * woutbuf = (ucs4_t *) malloc(sizeof(ucs4_t) * (wbufsize + 1));
 
 	ucs4_t * pinbuf = winbuf;
@@ -155,6 +156,7 @@ opencc_t opencc_open(const char * config_file)
 
 	opencc->dictionary_set = NULL;
 	opencc->converter = converter_open();
+	converter_set_conversion_mode(opencc->converter, OPENCC_CONVERSION_FAST);
 
 	/* 加載默認辭典 */
 	int retval;
@@ -227,6 +229,16 @@ int opencc_dict_load(opencc_t t_opencc, const char * dict_filename,
 	return retval;
 }
 
+void opencc_set_conversion_mode(opencc_t t_opencc, opencc_conversion_mode conversion_mode)
+{
+	if (!lib_initialized)
+		lib_initialize();
+
+	opencc_desc * opencc = (opencc_desc *) t_opencc;
+
+	converter_set_conversion_mode(opencc->converter, conversion_mode);
+}
+
 opencc_error opencc_errno(void)
 {
 	if (!lib_initialized)
